@@ -1,4 +1,5 @@
 import json
+import os
 import os.path
 from tempfile import NamedTemporaryFile
 from typing import Generator
@@ -10,6 +11,11 @@ from chaoslib.settings import load_settings
 from chaoslib.types import Settings
 
 
+@pytest.fixture
+def fixtures_dir() -> str:
+    return os.path.join(os.path.dirname(__file__), "fixtures")
+
+
 @pytest.fixture
 def settings_file() -> str:
     return os.path.join(os.path.dirname(__file__), "fixtures", "settings.yaml")
@@ -26,3 +32,13 @@ def generic_experiment() -> Generator[str, None, None]:
         json.dump(experiments.Experiment, f)
         f.seek(0)
         yield f.name
+
+
+@pytest.fixture(autouse=True)
+def reset_env() -> None:
+    e = os.environ.copy()
+    try:
+        yield
+    finally:
+        os.environ.clear()
+        os.environ.update(e)
