@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 from itertools import count
 
 from chaoslib.exceptions import InterruptExecution
 
-__all__ = ["interrupt_me", "raise_exception", "check_under_treshold",
-           "count_generator"]
+__all__ = ["interrupt_me", "raise_exception", "check_under_treshold", "count_generator"]
 
 
 def interrupt_me():
@@ -16,6 +14,8 @@ def raise_exception():
 
 
 g = None
+
+
 def count_generator():
     global g
     if g is None:
